@@ -145,6 +145,9 @@ def isFalse(environmentKey, default=True, evaluateItInsted=None):
             return c.FALSE == c.FALSE if isinstance(default, bool) and not default else c.TRUE
     return default
 
+def execute(commandLine):
+    return OS.system(commandLine)
+
 def listDirectoryContent(path):
     return OS.listdir(path)
 
@@ -154,10 +157,34 @@ def isDirectory(path):
 def isFile(path):
     return OS.path.isfile(path)
 
+def getCurrentDirectory():
+    return OS.getcwd()
+
+def getParentDirectory(path):
+    return OS.path.dirname(path)
+
+def cdDirectory(path):
+    return OS.chdir(path)
+
+def cdBack():
+    return cdDirectory(getParentDirectory(getCurrentDirectory()))
+
+def copyFile(filePath, asFilePath):
+    sourceAndDestination = f'{filePath}{c.SPACE}{asFilePath}'
+    if isLinux() or isMacOs():
+        return execute(f'cp{c.SPACE}{sourceAndDestination}')
+    if isWindows():
+        return execute(f'copy{c.SPACE}{sourceAndDestination}')
+
+def removeFile(filePath):
+    if isLinux() or isMacOs():
+        return execute(f'rm{c.SPACE}{c.DASH}rf{c.SPACE}{filePath}')
+    if isWindows():
+        return execute(f'cmd{c.SPACE}{c.FOWARD_SLASH}C{c.SPACE}rmdir{c.SPACE}{c.FOWARD_SLASH}S{c.SPACE}{c.FOWARD_SLASH}Q{c.SPACE}{filePath}')
+
 def makeDirectory(path, accessRights=0o777):
     ###- accessRights = 0o777 --> write, access and read
     ###- accessRights = 0o755 --> access and read
-    ###- accessRights = 0o755 --> access and read
     return OS.makedirs(path, mode=accessRights)
 
 def buildPath(*args):
